@@ -77,39 +77,29 @@ bool Database::addStation(const QString &title,
         return false;
     }
 
-    QSqlQuery query;
+    QSqlQuery query;    
+    query.prepare("INSERT INTO stations VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
+    qsrand(QDateTime::currentMSecsSinceEpoch());
+    int id = qrand();
+    query.addBindValue(id);
+    query.addBindValue(title);
+    query.addBindValue(description);
+    query.addBindValue(genre);
+    query.addBindValue(country);
+    query.addBindValue(language);
+    query.addBindValue(source);
+    query.addBindValue(favourite ? 1 : 0);
+    query.addBindValue(0);
 
-    if (query.exec("SELECT COUNT (*) FROM stations")) {
-        QSqlRecord record = query.record();
+    if (query.exec()) {
+        this->addGenre(genre);
+        this->addCountry(country);
+        this->addLanguage(language);
 
-        if ((record.count()) && (query.next())) {
-            int id = query.value(0).toInt() + 1; // TODO: CHANGE THIS
-            query.prepare("INSERT INTO stations VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
-            query.addBindValue(id);
-            query.addBindValue(title);
-            query.addBindValue(description);
-            query.addBindValue(genre);
-            query.addBindValue(country);
-            query.addBindValue(language);
-            query.addBindValue(source);
-            query.addBindValue(favourite ? 1 : 0);
-            query.addBindValue(0);
+        emit stationAdded();
+        emit alert(QString("%1 '%2' %3").arg(tr("New station")).arg(title).arg(tr("added")));
 
-            if (query.exec()) {
-                this->addGenre(genre);
-                this->addCountry(country);
-                this->addLanguage(language);
-
-                emit stationAdded();
-                emit alert(QString("%1 '%2' %3").arg(tr("New station")).arg(title).arg(tr("added")));
-
-                return true;
-            }
-        }
-
-        emit error(tr("Cannot add new station"));
-
-        return false;
+        return true;
     }
 
     emit error(tr("Cannot add new station"));
