@@ -15,27 +15,28 @@
  * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <QNetworkAccessManager>
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QRegExp>
 #include <QDomDocument>
 #include <QDomElement>
-#include "utils.h"
 #include "streamextractor.h"
+#include "utils.h"
+#include "networkaccessmanager.h"
 
 #define MAX_RETRIES 2
 
 StreamExtractor::StreamExtractor(QObject *parent) :
     QObject(parent),
-    m_nam(new QNetworkAccessManager(this)),
+    m_nam(new NetworkAccessManager(this)),
     m_retries(MAX_RETRIES)
 {
 }
 
 StreamExtractor::StreamExtractor(QNetworkAccessManager *manager, QObject *parent) :
     QObject(parent),
-    m_nam(!manager ? new QNetworkAccessManager(this) : manager)
+    m_nam(!manager ? new NetworkAccessManager(this) : manager),
+    m_retries(MAX_RETRIES)
 {
 }
 
@@ -61,6 +62,13 @@ void StreamExtractor::getStreamUrl(const QUrl &url) {
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
 }
 
+void StreamExtractor::retry(const QUrl &url) {
+    QNetworkRequest request(url);
+    QNetworkReply *reply = m_nam->get(request);
+    this->connect(reply, SIGNAL(finished()), this, SLOT(parseResponse()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+}
+
 void StreamExtractor::parseResponse() {
     QNetworkReply *reply = qobject_cast<QNetworkReply*>(this->sender());
 
@@ -84,7 +92,13 @@ void StreamExtractor::parseResponse() {
     QUrl redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
 
     if (!redirect.isEmpty()) {
-        this->getStreamUrl(redirect);
+        if (this->retries()) {
+            this->setRetries(this->retries() - 1);
+            this->retry(redirect);
+        }
+        else {
+            emit error(tr("Cannot find stream url"));
+        }
     }
     else {
         QString response(reply->readAll());
@@ -95,9 +109,14 @@ void StreamExtractor::parseResponse() {
             emit error(tr("Cannot find stream url"));
         }
         else {
-            if ((Utils::urlIsPlaylist(url)) && (this->retries())) {
-                this->setRetries(this->retries() - 1);
-                this->getStreamUrl(url);
+            if (Utils::urlIsPlaylist(url)) {
+                if (this->retries()) {
+                    this->setRetries(this->retries() - 1);
+                    this->retry(url);
+                }
+                else {
+                    emit error(tr("Cannot find stream url"));
+                }
             }
             else {
                 emit gotStreamUrl(url);
