@@ -16,6 +16,7 @@
  */
 
 #include <QApplication>
+#include <QTranslator>
 #include <QDeclarativeView>
 #include <QDeclarativeEngine>
 #include <QDeclarativeContext>
@@ -46,6 +47,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<StationFilterListModel>("com.cuteradio.models", 1, 0, "StationListModel");
     qmlRegisterType<PairListModel>("com.cuteradio.models", 1, 0, "PairListModel");
     qmlRegisterType<ScreenOrientationModel>("com.cuteradio.models", 1, 0, "ScreenOrientationModel");
+    qmlRegisterType<LanguageModel>("com.cuteradio.models", 1, 0, "LanguageModel");
     qmlRegisterType<ActiveColorModel>("com.cuteradio.models", 1, 0, "ActiveColorModel");
     qmlRegisterType<Station>("com.cuteradio.items", 1, 0, "Station");
 
@@ -59,6 +61,14 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     MediaPlayer player;
     SearchListModel searchModel;
 
+    if (!settings.language().isEmpty()) {
+        QTranslator translator;
+        translator.load(QString("/opt/cuteradio/translations/%1").arg(settings.language()));
+        app.data()->installTranslator(&translator);
+    }
+
+    settings.setNetworkProxy();
+
     QDeclarativeContext *context = view.data()->rootContext();
     context->setContextProperty("Settings", &settings);
     context->setContextProperty("Utils", &utils);
