@@ -128,7 +128,7 @@ void NowPlayingWindow::connectPlaybackSignals() {
     MediaPlayer::instance()->setTickInterval(1000);
     this->connect(MediaPlayer::instance(), SIGNAL(currentStationChanged(Station*)), this, SLOT(onCurrentStationChanged(Station*)), Qt::UniqueConnection);
     this->connect(MediaPlayer::instance(), SIGNAL(metaDataChanged()), this, SLOT(onMetaDataChanged()), Qt::UniqueConnection);
-    this->connect(MediaPlayer::instance(), SIGNAL(stateChanged(Phonon::State)), this, SLOT(onPlaybackStateChanged()), Qt::UniqueConnection);
+    this->connect(MediaPlayer::instance(), SIGNAL(stateChanged(MediaState::State)), this, SLOT(onPlaybackStateChanged()), Qt::UniqueConnection);
     this->connect(MediaPlayer::instance(), SIGNAL(positionChanged(qint64)), this, SLOT(onPlaybackPositionChanged(qint64)), Qt::UniqueConnection);
     this->connect(MediaPlayer::instance(), SIGNAL(sleepTimerEnabledChanged(bool)), this, SLOT(onSleepTimerEnabledChanged(bool)), Qt::UniqueConnection);
     this->connect(MediaPlayer::instance(), SIGNAL(sleepTimerRemainingChanged(qint64)), this, SLOT(onSleepTimerRemainingChanged(qint64)), Qt::UniqueConnection);
@@ -142,7 +142,7 @@ void NowPlayingWindow::disconnectPlaybackSignals() {
     MediaPlayer::instance()->setTickInterval(0);
     this->disconnect(MediaPlayer::instance(), SIGNAL(currentStationChanged(Station*)), this, SLOT(onCurrentStationChanged(Station*)));
     this->disconnect(MediaPlayer::instance(), SIGNAL(metaDataChanged()), this, SLOT(onMetaDataChanged()));
-    this->disconnect(MediaPlayer::instance(), SIGNAL(stateChanged(Phonon::State)), this, SLOT(onPlaybackStateChanged()));
+    this->disconnect(MediaPlayer::instance(), SIGNAL(stateChanged(MediaState::State)), this, SLOT(onPlaybackStateChanged()));
     this->disconnect(MediaPlayer::instance(), SIGNAL(positionChanged(qint64)), this, SLOT(onPlaybackPositionChanged(qint64)));
     this->disconnect(MediaPlayer::instance(), SIGNAL(sleepTimerEnabledChanged(bool)), this, SLOT(onSleepTimerEnabledChanged(bool)));
     this->disconnect(MediaPlayer::instance(), SIGNAL(sleepTimerRemainingChanged(qint64)), this, SLOT(onSleepTimerRemainingChanged(qint64)));
