@@ -16,6 +16,7 @@
  */
 
 #include <QApplication>
+#include <QTranslator>
 #include <QDeclarativeView>
 #include <QDeclarativeEngine>
 #include <QDeclarativeContext>
@@ -49,7 +50,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<PairListModel>("com.cuteradio.models", 1, 0, "PairListModel");
     qmlRegisterType<ScreenOrientationModel>("com.cuteradio.models", 1, 0, "ScreenOrientationModel");
     qmlRegisterType<LanguageModel>("com.cuteradio.models", 1, 0, "LanguageModel");
-    qmlRegisterType<ActiveColorModel>("com.cuteradio.models", 1, 0, "ActiveColorModel");
     qmlRegisterType<Station>("com.cuteradio.items", 1, 0, "Station");
 
     qmlRegisterUncreatableType<ScreenOrientation>("com.cuteradio.enums", 1, 0, "ScreenOrientation", "Y U create enum?");
@@ -64,7 +64,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     if (!settings.language().isEmpty()) {
         QTranslator translator;
-        translator.load(QString("%1/translations/%1").arg(QApplication::applicationDirPath()).arg(settings.language()));
+        translator.load(QString("%1/translations/%2").arg(QApplication::applicationDirPath()).arg(settings.language()));
         app.data()->installTranslator(&translator);
     }
 
